@@ -206,7 +206,9 @@ static int time_shutdown = 0;
 char *
 disk_mon_get_mount_point(char *dir)
 {
+    struct mntent mntbuf;
     struct mntent *mnt;
+    char buf[4096 + 1] = {0}; /* enough for 2 paths */
     struct stat s;
     dev_t dev_id;
     FILE *fp;
@@ -219,7 +221,7 @@ disk_mon_get_mount_point(char *dir)
     if ((fp = setmntent("/proc/mounts", "r")) == NULL) {
         return NULL;
     }
-    while ((mnt = getmntent(fp))) {
+    while ((mnt = getmntent_r(fp, &mntbuf, buf, 4096))) {
         if (stat(mnt->mnt_dir, &s) != 0) {
             continue;
         }
@@ -2460,6 +2462,8 @@ configure_pr_socket(PRFileDesc **pr_socket, int secure, int local)
     int ns = 0;
     int reservedescriptors = config_get_reservedescriptors();
     int enable_nagle = config_get_nagle();
+    int fin_timeout = config_get_tcp_fin_timeout();
+    int keepalive_time = config_get_tcp_keepalive_time();
 
     PRSocketOptionData pr_socketoption;
 
@@ -2552,6 +2556,20 @@ configure_pr_socket(PRFileDesc **pr_socket, int secure, int local)
         }
     } /* else (!enable_nagle) */
 
+    if (!local) {
+        if (setsockopt(ns, IPPROTO_TCP, TCP_LINGER2, (void *)&fin_timeout, sizeof(fin_timeout)) == -1) {
+            slapi_log_err(SLAPI_LOG_ERR,
+                          "configure_pr_socket", "setsockopt(TCP_LINGER2) failed, error %d (%s)\n",
+                          errno, strerror(errno));
+        }
+
+        if (setsockopt(ns, IPPROTO_TCP, TCP_KEEPIDLE, (void *)&keepalive_time, sizeof(keepalive_time)) == -1) {
+            slapi_log_err(SLAPI_LOG_ERR,
+                          "configure_pr_socket", "setsockopt(TCP_KEEPIDLE) failed, error %d (%s)\n",
+                          errno, strerror(errno));
+        }
+    }
+
     return ns;
 }
 
