@@ -135,7 +135,7 @@ export class LDAPEditor extends React.Component {
 
             const keyIndex = this.state.keyIndex + 1;
             this.setState({
-                entryMenuIsOpen: true,
+                entryMenuIsOpen: false,
                 wizardName: aTarget.name,
                 isTreeWizardOpen: true,
                 isWizardOpen: false,
@@ -192,7 +192,8 @@ export class LDAPEditor extends React.Component {
     handleReload(refresh) {
         const params = {
             serverId: this.props.serverId,
-            baseDn: this.state.baseDN
+            baseDn: this.state.baseDN,
+            addNotification: this.props.addNotification,
         };
 
         this.setState({
@@ -209,7 +210,8 @@ export class LDAPEditor extends React.Component {
                 const params = {
                     serverId: this.props.serverId,
                     baseDn: suffixDN,
-                    parentId: parentId
+                    parentId: parentId,
+                    addNotification: this.props.addNotification,
                 };
 
                 getRootSuffixEntryDetails(params, this.updateTableRootSuffixes);
@@ -305,7 +307,8 @@ export class LDAPEditor extends React.Component {
             });
             const params = {
                 serverId: this.props.serverId,
-                baseDn: id
+                baseDn: id,
+                addNotification: this.props.addNotification,
             };
             getOneLevelEntries(params, this.processDirectChildren);
         }
@@ -365,18 +368,20 @@ export class LDAPEditor extends React.Component {
         });
         const params = {
             serverId: this.props.serverId,
-            baseDn: dn
+            baseDn: dn,
+            addNotification: this.props.addNotification,
         };
         getOneLevelEntries(params, this.processDirectChildren);
     }
 
     // Process the entries that are direct children.
-    processDirectChildren = (directChildren) => {
+    processDirectChildren = (directChildren, params) => {
         this.setState({
             loading: true
         });
         const childrenRows = [];
         let rowNumber = 0;
+
         directChildren.map(aChild => {
             const info = JSON.parse(aChild);
             const numSubCellInfo = parseInt(info.numSubordinates) > 0
@@ -647,7 +652,8 @@ export class LDAPEditor extends React.Component {
                 const params = {
                     serverId: this.props.serverId,
                     baseDn: suffixDN,
-                    parentId: parentId
+                    parentId: parentId,
+                    addNotification: this.props.addNotification,
                 };
                 getRootSuffixEntryDetails(params, this.updateTableRootSuffixes);
                 parentId += 2; // The next DN row will be two rows below.
@@ -767,6 +773,19 @@ export class LDAPEditor extends React.Component {
                     });
                 }
             },
+            {
+                title: 'Class of Service ...',
+                onClick:
+                () => {
+                    this.setState({
+                        wizardName: ENTRY_MENU.cos,
+                        wizardEntryDn: rowData.rawdn,
+                        isWizardOpen: true,
+                        isTreeWizardOpen: false,
+                        keyIndex,
+                    });
+                }
+            },
             /*
             {
                 title: 'Roles ...',
@@ -883,22 +902,25 @@ export class LDAPEditor extends React.Component {
                             onReload={this.handleReload}
                             refreshing={this.state.refreshing}
                             allObjectclasses={this.state.allObjectclasses}
+                            addNotification={this.props.addNotification}
                         />
                     </Tab>
                     <Tab eventKey={1} title={<TabTitleText>Table View</TabTitleText>}>
-                        <Breadcrumb className="ds-left-margin ds-margin-top-xlg">
-                            {navItems.map(({ id, to, label, active }) => (
-                                <BreadcrumbItem key={id + label} to={to} isActive={active} onClick={() => this.onNavItemClick(id, active) }>
-                                    {label}
-                                </BreadcrumbItem>
-                            ))}
-                        </Breadcrumb>
-                        <FontAwesomeIcon
-                            className="ds-left-margin ds-refresh"
-                            icon={faSyncAlt}
-                            title="Refresh"
-                            onClick={this.handleReload}
-                        />
+                        <div className={this.state.searching ? "ds-disabled" : ""}>
+                            <Breadcrumb className="ds-left-margin ds-margin-top-xlg">
+                                {navItems.map(({ id, to, label, active }) => (
+                                    <BreadcrumbItem key={id + label} to={to} isActive={active} onClick={() => this.onNavItemClick(id, active) }>
+                                        {label}
+                                    </BreadcrumbItem>
+                                ))}
+                            </Breadcrumb>
+                            <FontAwesomeIcon
+                                className="ds-left-margin ds-refresh"
+                                icon={faSyncAlt}
+                                title="Refresh"
+                                onClick={this.handleReload}
+                            />
+                        </div>
                         <div className={this.state.searching ? "ds-margin-top-xlg ds-center" : "ds-hidden"}>
                             <TextContent>
                                 <Text component={TextVariants.h3}>
@@ -922,6 +944,7 @@ export class LDAPEditor extends React.Component {
                                 onCollapse={this.handleCollapse}
                                 columns={columns}
                                 actionResolver={this.actionResolver}
+                                addNotification={this.props.addNotification}
                             />
                         </div>
                     </Tab>
@@ -933,6 +956,7 @@ export class LDAPEditor extends React.Component {
                             attributes={this.state.attributes}
                             searchBase={this.state.searchBase}
                             allObjectclasses={this.state.allObjectclasses}
+                            addNotification={this.props.addNotification}
                         />
                     </Tab>
                 </Tabs>
