@@ -238,6 +238,8 @@ export function getSearchEntries (params, resultCallback) {
     params.searchScope,
     '-l',
     params.timeLimit,
+    '-z',
+    params.sizeLimit,
     params.searchFilter,
     '*',
     '+'
@@ -258,7 +260,10 @@ export function getSearchEntries (params, resultCallback) {
       if (err.exit_status === 4) {
         console.log('Size limit hit'); // Use the partial data.
         searchResult = data;
-        // TODO: Check other relevant error codes ( 32, 53 ...)
+        params.addNotification(
+            "info",
+            `Size limit of ${params.sizeLimit} was exceeded.  The child entries of "${params.searchBase}" have been truncated.`
+        );
       } else {
         searchResult = null;
         resultCallback(null, { status: err.exit_status, msg: err.message });
@@ -336,7 +341,7 @@ export function getBaseLevelEntryAttributes (serverId, baseDn, entryAttributesCa
     `ldapsearch -LLL -o ldif-wrap=no -Y EXTERNAL -b "${baseDn}"` +
     ` -H ldapi://%2fvar%2frun%2fslapd-${serverId}.socket` +
     ` ${optionTimeLimit}` +
-    ' -s base "(|(objectClass=*)(objectClass=ldapSubEntry))" \\*' // +
+    ' -s base "(|(objectClass=*)(objectClass=ldapSubEntry))" nsRoleDN \\*' // +
     // ' | /usr/bin/head -c 150001' // Taking 1 additional character to check if the
     // the entry was indeed bigger than 150K.
   ];
@@ -515,17 +520,20 @@ export function getOneLevelEntries (params, oneLevelCallback) {
       searchResult = data;
     })
     .catch((err, data) => {
-    // .fail(err => {
       console.log('FAIL err.exit_status ==> ' + err.exit_status);
       console.log('FAIL err.message ==> ' + err.message);
       if (err.exit_status === 4) {
-        console.log('Size limit hit');
         // Use the partial data.
         searchResult = data;
-        // TODO: Check other relevant error codes ( 32, 53 ...)
+        const size_limit = getSizeLimit();
+        params.addNotification(
+            "info",
+            `Size limit of ${size_limit} was exceeded.  The child entries of "${params.baseDn}" have been truncated.  ` +
+            `Use the "Search" feature if you want to adjust the size limit and retrieve more entries`
+        );
       } else {
         searchResult = null;
-        oneLevelCallback(null, { status: err.exit_status, msg: err.message });
+        oneLevelCallback(null, params, { status: err.exit_status, msg: err.message });
       }
     })
     .finally(() => {
@@ -568,7 +576,7 @@ export function getOneLevelEntries (params, oneLevelCallback) {
         }
       });
       // Process the list of entries.
-      oneLevelCallback(allEntries, null);
+      oneLevelCallback(allEntries, params, null);
     });
 }
 
