@@ -55,10 +55,11 @@ export class SearchDatabase extends React.Component {
             searchBase: "",
             searchFilter: "",
             searchScope: "sub",
-            sizeLimit: 1000,
+            sizeLimit: 2000,
             timeLimit: 30,
             isExpanded: false,
             searchSuffix: "",
+            baseDN: "",
             searchType: 'Search Text',
             searchText: "",
             getOperationalAttrs: false,
@@ -201,6 +202,7 @@ export class SearchDatabase extends React.Component {
                 searchScope: this.state.searchScope,
                 sizeLimit: this.state.sizeLimit,
                 timeLimit: this.state.timeLimit,
+                addNotification: this.props.addNotification,
             };
             getSearchEntries(params, this.processResults);
         };
@@ -256,9 +258,17 @@ export class SearchDatabase extends React.Component {
     componentDidMount() {
         const suffixList =  this.props.suffixList;
         const searchBase = this.props.searchBase;
+        let baseDN = searchBase;  // Drop down list of selected suffix
+        for (const suffix of suffixList) {
+            if (baseDN.includes(suffix)) {
+                baseDN = suffix;
+                break;
+            }
+        }
         this.setState({
             searchBase: searchBase ? searchBase : suffixList.length > 0 ? suffixList[0] : "",
             searchSuffix: this.props.suffixList.length > 0 ? this.props.suffixList[0] : "",
+            baseDN: baseDN
         });
     }
 
@@ -294,7 +304,7 @@ export class SearchDatabase extends React.Component {
     }
 
     // Process the entries that are direct children.
-    processResults = (searchResults) => {
+    processResults = (searchResults, resObj) => {
         const resultRows = [];
         let rowNumber = 0;
 
@@ -332,6 +342,13 @@ export class SearchDatabase extends React.Component {
                 // Increment by 2 the row number.
                 rowNumber += 2;
             });
+        } else {
+            if (resObj.status !== 0) {
+                this.props.addNotification(
+                    "error",
+                    `Error searching the database: ${resObj.msg}`
+                );
+            }
         }
 
         this.setState({
@@ -362,6 +379,7 @@ export class SearchDatabase extends React.Component {
         this.setState({
             searchSuffix: value,
             searchBase: value,
+            baseDN: value,
         });
     }
 
@@ -385,8 +403,7 @@ export class SearchDatabase extends React.Component {
             const start = 2 * (page - 1) * perPage;
             const end = 2 * page * perPage;
             const pagedRows = this.state.rows.slice(start, end);
-            let i = 0;
-            for (i; i < pagedRows.length - 1; i++) {
+            for (let i = 0; i < pagedRows.length - 1; i++) {
                 if (i % 2 === 0) {
                     pagedRows[i + 1].parent = i;
                 }
@@ -541,7 +558,7 @@ export class SearchDatabase extends React.Component {
                                 <GridItem span={4}>
                                     <FormSelect
                                         id="searchSuffix"
-                                        value={this.state.searchSuffix}
+                                        value={this.state.baseDN}
                                         onChange={(value, event) => {
                                             this.handleSuffixChange(event);
                                         }}
@@ -853,7 +870,7 @@ export class SearchDatabase extends React.Component {
                     </ExpandableSection>
                 </Form>
                 <div className="ds-indent">
-                    <div className={this.state.searching ? "ds-margin-top-xlg ds-center" : "ds-hidden"}>
+                    <div className={this.state.searching ? "ds-margin-top-lg ds-center" : "ds-hidden"}>
                         <TextContent>
                             <Text component={TextVariants.h3}>
                                 Searching <i>{this.state.searchBase}</i> ...
@@ -862,6 +879,9 @@ export class SearchDatabase extends React.Component {
                         <Spinner className="ds-margin-top-lg" size="xl" />
                     </div>
                     <div className={searching ? "ds-hidden" : ""}>
+                        <center>
+                            <p><b>Results:</b> {total}</p>
+                        </center>
                         <EditorTableView
                             key={searching}
                             loading={searching}
