@@ -75,7 +75,6 @@ class EditorTreeView extends React.Component {
             alerts: [],
             firstClickOnTree: false,
             searchInput: '',
-            entryMenuIsOpen: false,
             rowsValues: [],
             entryColumns: [
                 { title: 'Attribute' },
@@ -117,6 +116,7 @@ class EditorTreeView extends React.Component {
                 this.updateEntryRows(treeViewItem);
                 return;
             }
+
             this.setState({
                 searching: true,
             }, () => {
@@ -132,18 +132,6 @@ class EditorTreeView extends React.Component {
             });
         };
 
-        this.entryOnToggle = isOpen => {
-            this.setState({
-                entryMenuIsOpen: isOpen
-            });
-        };
-
-        this.entryOnSelect = () => {
-            this.setState({
-                entryMenuIsOpen: !this.state.entryMenuIsOpen
-            });
-        };
-
         this.handleEmptySuffixToggle = (resultParams) => {
             this.setState(({ showEmptySuffixModal }) => ({
                 showEmptySuffixModal: !showEmptySuffixModal
@@ -173,6 +161,12 @@ class EditorTreeView extends React.Component {
         }
     }
 
+    showEntryLoading = (isEntryLoading) => {
+        this.setState({
+            searching: isEntryLoading ? true : false
+        });
+    };
+
     showTreeLoadingState = (isTreeLoading) => {
         this.setState({
             isTreeLoading,
@@ -195,6 +189,9 @@ class EditorTreeView extends React.Component {
             return;
         }
 
+        // Always close the drop down
+        this.props.onToggleEntryMenu(false);
+
         const entryRows = [];
         const isEmptySuffix = treeViewItem.isEmptySuffix;
         let entryIcon = treeViewItem.icon; // Only already set for special suffixes.
@@ -388,10 +385,12 @@ class EditorTreeView extends React.Component {
                     });
                 }
             });
+
             // Update the refresh time.
             this.setState({
                 latestEntryRefreshTime: Date.now(),
             });
+            this.showEntryLoading(false);
         });
     };
 
@@ -451,6 +450,14 @@ class EditorTreeView extends React.Component {
             >
                 ACIs ...
             </DropdownItem>,
+            <DropdownItem
+                key="tree-view-cos"
+                component="button"
+                name={ENTRY_MENU.cos}
+                value={entryDn}
+            >
+                Class of Service ...
+            </DropdownItem>,
             /*
             <DropdownItem
                 isDisabled
@@ -483,14 +490,27 @@ class EditorTreeView extends React.Component {
         ];
 
         const loadingStateComponent = (
-            <div className="ds-margin-top-xlg ds-center">
-                <TextContent>
-                    <Text component={TextVariants.h3}>
-                        Loading ...
-                    </Text>
-                </TextContent>
-                <Spinner className="ds-margin-top-lg" size="lg" />
-            </div>
+            <>
+                <div className="ds-margin-top-lg ds-indent">
+                    <Label icon={<CatalogIcon />} color="blue">
+                        <strong>{this.props.treeViewRootSuffixes.length > 1 ? "Suffix Trees" : "Suffix Tree"}</strong>
+                        <Button
+                            variant="link"
+                            title="Refresh all the suffixes"
+                            icon={<SyncAltIcon />}
+                            onClick={() => { this.props.onReload(true) }}
+                        />
+                    </Label>
+                </div>
+                <div className="ds-margin-top-xlg ds-center">
+                    <TextContent>
+                        <Text component={TextVariants.h3}>
+                            Loading ...
+                        </Text>
+                    </TextContent>
+                    <Spinner className="ds-margin-top-lg" size="lg" />
+                </div>
+            </>
         );
 
         const finishedAt = new Date();
@@ -562,6 +582,8 @@ class EditorTreeView extends React.Component {
                                     showTreeLoadingState={this.showTreeLoadingState}
                                     refreshButtonTriggerTime={refreshButtonTriggerTime}
                                     handleEntryRefresh={this.refreshEntry}
+                                    addNotification={this.props.addNotification}
+                                    isDisabled={isTreeLoading}
                                 />
                             }
                         </GridItem>
@@ -588,7 +610,7 @@ class EditorTreeView extends React.Component {
                             { searching && loadingStateComponent }
 
                             { firstClickOnTree && !loading && !searching && isValidData &&
-                                <Card isHoverable>
+                                <Card isSelectable>
                                     <CardHeader>
                                         <CardActions>
                                             <Dropdown
