@@ -6,7 +6,6 @@ import {
     Button,
     Card, CardHeader, CardBody, CardTitle,
     Dropdown, DropdownItem, DropdownPosition,
-    FormSelect, FormSelectOption,
     Grid, GridItem,
     Label, LabelGroup,
     Pagination,
@@ -91,6 +90,7 @@ class AddLdapEntry extends React.Component {
             selectedAttributes: [],
             attrsToRemove: [],
             namingAttr: "",
+            adding: true,
         };
 
         this.onNext = ({ id }) => {
@@ -116,7 +116,9 @@ class AddLdapEntry extends React.Component {
                     (result) => {
                         this.setState({
                             commandOutput: result.output,
-                            resultVariant: result.errorCode === 0 ? 'info' : 'danger'
+                            commandOutput: result.errorCode === 0 ? 'Successfully added entry!' : 'Failed to add entry, error: ' + result.errorCode ,
+                            resultVariant: result.errorCode === 0 ? 'success' : 'danger',
+                            adding: false,
                         }, () => { this.props.onReload() });
 
                         const myDn = this.state.ldifArray[0].substring(4);
@@ -430,8 +432,11 @@ class AddLdapEntry extends React.Component {
         const ocToProcess = [...this.state.selectedObjectClasses];
         const rowsAttr = [];
         const attrList = [];
+        let namingRowID = this.state.namingRowID;
+        let namingAttr = this.state.namingAttr;
+        let isNamingAttr = false;
 
-        ocToProcess.map(oc => {
+        for (let oc of ocToProcess) {
             // Rebuild the attribute arrays.
             const required = oc.cells[1].split(',');
             const optional = oc.cells[2].split(',');
@@ -465,9 +470,6 @@ class AddLdapEntry extends React.Component {
                 const found = this.state.editableTableData.filter(item => (item.attr.toLowerCase() === attr));
                 if (found.length === 0 && attr !== 'objectclass') {
                     const new_id = generateUniqueId();
-                    let namingRowID = this.state.namingRowID;
-                    let namingAttr = this.state.namingAttr;
-                    let isNamingAttr = false;
 
                     if (namingRowID === -1) {
                         namingRowID = new_id;
@@ -514,7 +516,7 @@ class AddLdapEntry extends React.Component {
                     });
                 }
             }
-        });
+        }
 
         // Update the rows where user can select the attributes.
         rowsAttr.sort((a, b) => (a.attributeName > b.attributeName) ? 1 : -1)
@@ -839,7 +841,7 @@ class AddLdapEntry extends React.Component {
                         title="LDIF Statements"
                     />
                 </div>
-                <Card isHoverable>
+                <Card isSelectable>
                     <CardBody>
                         { (ldifListItems.length > 0) &&
                             <SimpleList aria-label="LDIF data User">
@@ -866,10 +868,16 @@ class AddLdapEntry extends React.Component {
                         title="Result for Entry Modification"
                     >
                         {commandOutput}
+                        {this.state.adding &&
+                            <div>
+                                <Spinner className="ds-left-margin" size="md" />
+                                &nbsp;&nbsp;Adding entry ...
+                            </div>
+                        }
                     </Alert>
                 </div>
                 {resultVariant === 'danger' &&
-                    <Card isHoverable>
+                    <Card isSelectable>
                         <CardTitle>LDIF Data</CardTitle>
                         <CardBody>
                             {ldifLines.map((line) => (
@@ -916,7 +924,8 @@ class AddLdapEntry extends React.Component {
                 component: entryReviewStep,
                 nextButtonText: 'Finish',
                 canJumpTo: stepIdReached > 5,
-                hideBackButton: true
+                hideBackButton: true,
+                enableNext: !this.state.adding,
             }
         ];
 
