@@ -91,6 +91,7 @@ class EditLdapEntry extends React.Component {
             selectedObjectClasses: [],
             selectedAttributes: [],
             attrsToRemove: [],
+            modifying: true,
         };
 
         this.onNext = ({ id }) => {
@@ -117,7 +118,9 @@ class EditLdapEntry extends React.Component {
                     }
                     this.setState({
                         commandOutput: result.output,
-                        resultVariant: result.errorCode === 0 ? 'success' : 'danger'
+                        commandOutput: result.errorCode === 0 ? 'Successfully modified entry!' : 'Failed to modify entry, error: ' + result.errorCode ,
+                        resultVariant: result.errorCode === 0 ? 'success' : 'danger',
+                        modifying: false,
                     }, () => { this.props.onReload() }); // refreshes tableView
                     const opInfo = { // This is what refreshes treeView
                         operationType: 'MODIFY',
@@ -583,6 +586,34 @@ class EditLdapEntry extends React.Component {
                     });
                 }
             }
+
+            // If we're editing a user then add nsRoleDN attribute to the possible list
+            let personOC = false;
+            for (const existingOC of this.state.selectedObjectClasses) {
+                if (existingOC.cells[0].toLowerCase() === 'person' ||
+                   existingOC.cells[0].toLowerCase() === 'nsperson') {
+                    personOC = true;
+                    break;
+                }
+            }
+            let roleDNAttr = 'nsRoleDN'
+            if ((personOC && !attrList.includes(roleDNAttr))) {
+                let selected = false;
+                for (const existingRow of this.state.editableTableData) {
+                    if (existingRow.attr.toLowerCase() === roleDNAttr.toLowerCase()) {
+                        selected = true;
+                        break;
+                    }
+                }
+
+                attrList.push(roleDNAttr);
+                rowsAttr.push({
+                    attributeName: roleDNAttr,
+                    isAttributeSelected: selected,
+                    selected: selected,
+                    cells: [roleDNAttr, '']
+                });
+            }
         });
 
         // Update the rows where user can select the attributes.
@@ -1103,7 +1134,7 @@ class EditLdapEntry extends React.Component {
                         title="LDIF Statements"
                     />
                 </div>
-                <Card isHoverable>
+                <Card isSelectable>
                     <CardBody>
                         { (ldifListItems.length > 0) &&
                             <SimpleList aria-label="LDIF data User">
@@ -1130,10 +1161,16 @@ class EditLdapEntry extends React.Component {
                         title="Result for Entry Modification"
                     >
                         {commandOutput}
+                        {this.state.adding &&
+                            <div>
+                                <Spinner className="ds-left-margin" size="md" />
+                                &nbsp;&nbsp;Modifying entry ...
+                            </div>
+                        }
                     </Alert>
                 </div>
                 {resultVariant === 'danger' &&
-                    <Card isHoverable>
+                    <Card isSelectable>
                         <CardTitle>LDIF Data</CardTitle>
                         <CardBody>
                             {ldifLines.map((line) => (
@@ -1197,7 +1234,8 @@ class EditLdapEntry extends React.Component {
                 component: entryReviewStep,
                 nextButtonText: 'Finish',
                 canJumpTo: stepIdReached > 6,
-                hideBackButton: true
+                hideBackButton: true,
+                enableNext: !this.state.modifying
             }
         ];
 
