@@ -513,7 +513,7 @@ export class ReplConfig extends React.Component {
                     variant="primary"
                     onClick={this.showPromoteDemoteModal}
                     title="Demote this Supplier replica to a Hub or Consumer"
-                    className="ds-inline-btn"
+                    className="ds-left-margin"
                 >
                     Change Role
                 </Button>;
@@ -523,7 +523,7 @@ export class ReplConfig extends React.Component {
                     variant="primary"
                     onClick={this.showPromoteDemoteModal}
                     title="Promote or Demote this Hub replica to a Supplier or Consumer"
-                    className="ds-inline-btn"
+                    className="ds-left-margin"
                 >
                     Change Role
                 </Button>;
@@ -534,7 +534,7 @@ export class ReplConfig extends React.Component {
                     variant="primary"
                     onClick={this.showPromoteDemoteModal}
                     title="Promote this Consumer replica to a Supplier or Hub"
-                    className="ds-inline-btn"
+                    className="ds-left-margin"
                 >
                     Change Role
                 </Button>;
